# Display Settings

## Display Characteristics
* [Image Depth](./Image-Depth.md)
* [DPI](./DPI.md)
* [Client OpenGL](../Usage/Client-OpenGL.md)
* [Server OpenGL](../Usage/OpenGL.md)
* [Xdummy](../Usage/Xdummy.md)
* [Encodings](../Usage/Encodings.md)

## See also
* [Keyboard](./Keyboard.md)
* [System tray](./System-Tray.md)
* [Notifications](./Notifications.md)
